@@ -19,9 +19,9 @@ use Term::ANSIColor;
 use Log::Fast;
 use Time::HiRes qw(time);
 use File::Basename;
-use Best [ # Loads the first available module, in order of preference.
+use Best [    # Loads the first available module, in order of preference.
     [
-        'Data::Printer' => {'args' => {'colored' => TRUE,'use_prototypes' => FALSE}},
+        'Data::Printer' => {'args' => {'colored' => TRUE, 'use_prototypes' => FALSE}},
         'Data::Dumper::Simple',
         'Data::Dumper'
     ]
@@ -40,7 +40,7 @@ BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 1.05;
+    our $VERSION = 1.06;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -57,7 +57,7 @@ our @Levels = qw( ERR WARN NOTICE INFO VERBOSE DEBUG DEBUGMAX );
 
 # For quick level checks to speed up execution
 our %LevelLogic;
-for (my $count=0;$count<scalar(@Levels);$count++) {
+for (my $count = 0 ; $count < scalar(@Levels) ; $count++) {
     $LevelLogic{$Levels[$count]} = $count;
 }
 
@@ -79,7 +79,7 @@ Debug::Easy - A Handy Debugging Module With Colorized Output and Formatting
  my $debug = Debug::Easy->new( 'LogLevel' => 'DEBUG', 'Color' => 1 );
 
  # $debug_level is the maximum level to report, and ignore the rest.
- # It must be the second parameter passed to the object, when outputing
+ # It must be the first parameter passed to the object, when outputing
  # a specific message.  This identifies to the module what type of
  # message it is.
  #
@@ -181,10 +181,10 @@ Data::Dumper
 
 END {    # We spit out one last message before we die, the total execute time.
     my $bench = colored(['bright_cyan on_black'], sprintf('%06s', sprintf('%.02f', (time - $MASTERSTART))));
-    my $name  = $SCRIPTNAME;
+    my $name = $SCRIPTNAME;
     $name .= ' [child]' if ($PARENT ne $$);
     $LOG->DEBUG(' %s%s %s', $bench, $ANSILevel{'DEBUG'}, colored(['black on_white'], "---- $name complete ----")) if (defined($ANSILevel{'DEBUG'}) && defined($LOG));
-}
+} ## end END
 
 =head1 METHODS
 
@@ -404,38 +404,38 @@ sub new {
     # Log::Fast variables and features can work here.  See the perldocs
     # for Log::Fast for specifics.
     my $class = shift;
-    my ($filename,$dir,$suffix) = fileparse($0);
+    my ($filename, $dir, $suffix) = fileparse($0);
     my $self = {
-        'LogLevel'           => 'ERR',                                # Default is errors only
-        'Type'               => 'fh',                                 # Default is a filehandle
-        'Path'               => '/var/log',                           # Default path should type be unix
-        'FileHandle'         => \*STDERR,                             # Default filehandle is STDERR
-        'MasterStart'        => $MASTERSTART,                         # Pull in the script start timestamp
-        'ANY_LastStamp'      => time,                                 # Initialize main benchmark
-        'ERR_LastStamp'      => time,                                 # Initialize the ERR benchmark
-        'WARN_LastStamp'     => time,                                 # Initialize the WARN benchmark
-        'INFO_LastStamp'     => time,                                 # Initialize the INFO benchmark
-        'NOTICE_LastStamp'   => time,                                 # Initialize the NOTICE benchmark
-        'DEBUG_LastStamp'    => time,                                 # Initialize the DEBUG benchmark
-        'DEBUGMAX_LastStamp' => time,                                 # Initialize the DEBUGMAX benchmark
-        'LOG'                => $LOG,                                 # Pull in the global Log::Fast object.
-        'Color'              => TRUE,                                 # Default to colorized output
+        'LogLevel'           => 'ERR',                                   # Default is errors only
+        'Type'               => 'fh',                                    # Default is a filehandle
+        'Path'               => '/var/log',                              # Default path should type be unix
+        'FileHandle'         => \*STDERR,                                # Default filehandle is STDERR
+        'MasterStart'        => $MASTERSTART,                            # Pull in the script start timestamp
+        'ANY_LastStamp'      => time,                                    # Initialize main benchmark
+        'ERR_LastStamp'      => time,                                    # Initialize the ERR benchmark
+        'WARN_LastStamp'     => time,                                    # Initialize the WARN benchmark
+        'INFO_LastStamp'     => time,                                    # Initialize the INFO benchmark
+        'NOTICE_LastStamp'   => time,                                    # Initialize the NOTICE benchmark
+        'DEBUG_LastStamp'    => time,                                    # Initialize the DEBUG benchmark
+        'DEBUGMAX_LastStamp' => time,                                    # Initialize the DEBUGMAX benchmark
+        'LOG'                => $LOG,                                    # Pull in the global Log::Fast object.
+        'Color'              => TRUE,                                    # Default to colorized output
         'DateStamp'          => colored(['yellow on_black'], '%date%'),
         'TimeStamp'          => colored(['yellow on_black'], '%time%'),
-        'Padding'            => -20,                                  # Default padding is 20 spaces
-        'CPadding'           => -2,
-        'SPadding'           => 0,
-        'LPadding'           => 0,
+        'Padding'            => -20,                                     # Default padding is 20 spaces
+        'Lines-Padding'      => -2,
+        'Subroutine-Padding' => 0,
+        'Line-Padding'       => 0,
         'Prefix'             => '%Date% %Time% %Benchmark% %Loglevel%[%Subroutine%][%Lastline%] ',
         'DEBUGMAX-Prefix'    => '%Date% %Time% %Benchmark% %Loglevel%[%Module%][%Lines%] ',
-        'Filename'           => '[' . colored(['magenta'],$filename) . ']',
+        'Filename'           => '[' . colored(['magenta'], $filename) . ']',
         'ANSILevel'          => {
-            'ERR'       => colored(['white on_red'],        '[ ERROR ]'),
-            'WARN'      => colored(['black on_yellow'],     '[WARNING]'),
-            'NOTICE'    => colored(['yellow'],              '[NOTICE ]'),
-            'INFO'      => colored(['black on_white'],      '[ INFO  ]'),
-            'DEBUG'     => colored(['bold green'],          '[ DEBUG ]'),
-            'DEBUGMAX'  => colored(['bold black on_green'], '[DEBUGMX]'),
+            'ERR'      => colored(['white on_red'],        '[ ERROR ]'),
+            'WARN'     => colored(['black on_yellow'],     '[WARNING]'),
+            'NOTICE'   => colored(['yellow'],              '[NOTICE ]'),
+            'INFO'     => colored(['black on_white'],      '[ INFO  ]'),
+            'DEBUG'    => colored(['bold green'],          '[ DEBUG ]'),
+            'DEBUGMAX' => colored(['bold black on_green'], '[DEBUGMX]'),
         },
         @_
     };
@@ -448,13 +448,13 @@ sub new {
             # This fixes a documentation error for past versions
             if ($upper eq 'LOGLEVEL') {
                 $self->{$upper} = 'ERR' if ($self->{$upper} =~ /^ERROR$/i);
-                $self->{$upper} = uc($self->{$upper}); # Make loglevels case insensitive
+                $self->{$upper} = uc($self->{$upper});    # Make loglevels case insensitive
             }
             delete($self->{$Key});
-        } elsif ($Key eq 'LOGLEVEL') { # Make loglevels case insensitive
+        } elsif ($Key eq 'LOGLEVEL') {    # Make loglevels case insensitive
             $self->{$upper} = uc($self->{$upper});
         }
-    }
+    } ## end foreach my $Key (@Keys)
 
     # This instructs the ANSIColor library to turn off coloring,
     # if the Color attribute is set to zero.
@@ -463,18 +463,19 @@ sub new {
     # If COLOR is FALSE, then clear color data from ANSILEVEL, as these were
     # defined before color was turned off.
     $self->{'ANSILEVEL'} = {
-        'ERR'       => '[ ERROR ]',
-        'WARN'      => '[WARNING]',
-        'NOTICE'    => '[NOTICE ]',
-        'INFO'      => '[ INFO  ]',
-        'DEBUG'     => '[ DEBUG ]',
-        'DEBUGMAX'  => '[DEBUGMX]',
+        'ERR'      => '[ ERROR ]',
+        'WARN'     => '[WARNING]',
+        'NOTICE'   => '[NOTICE ]',
+        'INFO'     => '[ INFO  ]',
+        'DEBUG'    => '[ DEBUG ]',
+        'DEBUGMAX' => '[DEBUGMX]',
     } if ($self->{'COLOR'} =~ /0|FALSE|OFF|NO/i);
     %ANSILevel = %{$self->{'ANSILEVEL'}};
 
     foreach my $lvl (@Levels) {
         $self->{"$lvl-PREFIX"} = $self->{'PREFIX'} unless (defined($self->{"$lvl-PREFIX"}));
     }
+
     # The Global loglevel is set here.
     if ($self->{'LOGLEVEL'} eq 'VERBOSE') {
         $self->{'LOG'}->level('INFO');
@@ -484,7 +485,7 @@ sub new {
         $self->{'LOG'}->level($self->{'LOGLEVEL'});
     }
 
-    $self->{'LOG'}->config( # Configure Log::Fast
+    $self->{'LOG'}->config(    # Configure Log::Fast
         {
             'type'   => $self->{'TYPE'},
             'path'   => $self->{'PATH'},
@@ -492,8 +493,9 @@ sub new {
             'fh'     => $self->{'FILEHANDLE'}
         }
     );
+
     # Signal the script has started (and logger initialized)
-    my $name  = $SCRIPTNAME;
+    my $name = $SCRIPTNAME;
     $name .= ' [child]' if ($PARENT ne $$);
     $self->{'LOG'}->DEBUG('   %.02f%s %s', 0, $self->{'ANSILEVEL'}->{'DEBUG'}, colored(['black on_white'], "----- $name begin -----"));
     bless($self, $class);
@@ -523,11 +525,11 @@ sub debug {
     my $level = uc(shift);
     my $msgs  = shift;
 
-    if ($level !~ /ERR.*|WARN.*|NOTICE|INFO.*|DEBUG/i) { # Compatibility with older versions.
-        $level = $msgs;                                  # It tosses the legacy __LINE__ argument
+    if ($level !~ /ERR.*|WARN.*|NOTICE|INFO.*|DEBUG/i) {    # Compatibility with older versions.
+        $level = $msgs;                                     # It tosses the legacy __LINE__ argument
         $msgs  = shift;
     }
-    $level = 'ERR'  if ($level eq 'ERROR');      # This allows the programmer to use either
+    $level = 'ERR'  if ($level eq 'ERROR');                 # This allows the programmer to use either
     $level = 'WARN' if ($level eq 'WARNING');
     $level = 'INFO' if ($level eq 'INFORMATION');
 
@@ -541,28 +543,25 @@ sub debug {
         @messages = @{$msgs};
     } else {
         if ($Modules->{'Data::Printer'}) {
-            eval {
-                push(@messages, p($msgs));
-            };
+            eval {push(@messages, p($msgs));};
         } else {
-            eval {
-                push(@messages, Dumper($msgs));
-            };
+            eval {push(@messages, Dumper($msgs));};
         }
-    }
-    my ($sname,$cline,$nested,$subroutine,$thisBench,$thisBench2,$sline,$short) = ('','','','','','','','');
+    } ## end else [ if (ref($msgs) eq 'SCALAR'...)]
+    my ($sname, $cline, $nested, $subroutine, $thisBench, $thisBench2, $sline, $short) = ('', '', '', '', '', '', '', '');
+
     # Figure out the proper caller tree and line number ladder
     # But only if it's part of the prefix, else don't waste time.
-    if ($self->{'PREFIX'} =~ /\%(Subroutine|Module|Lines|Lastline)\%/) { # %P = Subroutine, %l = Line number(s)
+    if ($self->{'PREFIX'} =~ /\%(Subroutine|Module|Lines|Lastline)\%/) {    # %P = Subroutine, %l = Line number(s)
         my $package = '';
         my $count   = 1;
         my $nest    = 0;
         while (my @array = caller($count)) {
             if ($array[3] !~ /Debug::Easy/) {
-                $package       = $array[0];
+                $package = $array[0];
                 my $subroutine = $array[3];
                 $subroutine =~ s/^$package\:\://;
-                $sname      =~ s/$subroutine//;
+                $sname =~ s/$subroutine//;
                 if ($sname eq '') {
                     $sname = ($subroutine ne '') ? $subroutine : $package;
                     $cline = $array[2];
@@ -575,9 +574,9 @@ sub debug {
                     $sline = $array[2];
                 }
                 $nest++;
-            }
+            } ## end if ($array[3] !~ /Debug::Easy/)
             $count++;
-        }
+        } ## end while (my @array = caller...)
         if ($package ne '') {
             $sname = $package . '::' . $sname;
             $nested = ' ' x $nest if ($nest);
@@ -591,53 +590,51 @@ sub debug {
             $sname = 'main';
             $sline = $cline;
             $short = $sname;
-        }
+        } ## end else [ if ($package ne '') ]
         $subroutine = $sname;
-        $self->{'PADDING'}  = 0 - length($subroutine) if (length($subroutine) > abs($self->{'PADDING'}));
-        $self->{'CPADDING'} = 0 - length($cline) if (length($cline) > abs($self->{'CPADDING'}));
-        $self->{'SPADDING'} = 0 - length($short) if (length($short) > abs($self->{'SPADDING'}));
-        $self->{'LPADDING'} = 0 - length($sline) if (length($sline) > abs($self->{'LPADDING'}));
-        $cline              = sprintf('%' . $self->{'CPADDING'} . 's',$cline);
-        $subroutine         = colored(['bold cyan'],sprintf('%' . $self->{'PADDING'} . 's',$subroutine));
-        $sline              = sprintf('%' . $self->{'LPADDING'} . 's',$sline);
-        $short              = colored(['bold cyan'],sprintf('%' . $self->{'SPADDING'} . 's',$short));
-    }
+        $self->{'PADDING'}            = 0 - length($subroutine) if (length($subroutine) > abs($self->{'PADDING'}));
+        $self->{'LINES-PADDING'}      = 0 - length($cline)      if (length($cline) > abs($self->{'LINES-PADDING'}));
+        $self->{'SUBROUTINE-PADDING'} = 0 - length($short)      if (length($short) > abs($self->{'SUBROUTINE-PADDING'}));
+        $self->{'LINE-PADDING'}       = 0 - length($sline)      if (length($sline) > abs($self->{'LINE-PADDING'}));
+        $cline = sprintf('%' . $self->{'LINES-PADDING'} . 's', $cline);
+        $subroutine = colored(['bold cyan'], sprintf('%' . $self->{'PADDING'} . 's', $subroutine));
+        $sline = sprintf('%' . $self->{'LINE-PADDING'} . 's', $sline);
+        $short = colored(['bold cyan'], sprintf('%' . $self->{'SUBROUTINE-PADDING'} . 's', $short));
+    } ## end if ($self->{'PREFIX'} ...)
+
     # Figure out the benchmarks, but only if it is in the prefix
     if ($self->{'PREFIX'} =~ /\%Benchmark\%/) {
+
         # For multiline output, only output the bench data on the first line.  Use padded spaces for the rest.
-#        $thisBench  = sprintf('%7s', sprintf(' %.02f', time - $self->{$level . '_LASTSTAMP'}));
-        $thisBench  = sprintf('%7s', sprintf(' %.02f', time - $self->{'ANY_LASTSTAMP'}));
+        #        $thisBench  = sprintf('%7s', sprintf(' %.02f', time - $self->{$level . '_LASTSTAMP'}));
+        $thisBench = sprintf('%7s', sprintf(' %.02f', time - $self->{'ANY_LASTSTAMP'}));
         $thisBench2 = ' ' x length($thisBench);
-    }
-    my $first = TRUE;                      # Set the first line flag.
-    foreach my $msg (@messages) {          # Loop through each line of output and format accordingly.
+    } ## end if ($self->{'PREFIX'} ...)
+    my $first = TRUE;    # Set the first line flag.
+    foreach my $msg (@messages) {    # Loop through each line of output and format accordingly.
         if (ref($msg) ne '') {
             if ($Modules->{'Data::Printer'}) {
-                eval {
-                    $msg = p($msg);
-                };
+                eval {$msg = p($msg);};
             } else {
-                eval {
-                    $msg = Dumper($msg);
-                };
+                eval {$msg = Dumper($msg);};
             }
-        }
-        if ($msg =~ /\n/s) {               # If the line contains newlines, then it too must be split into multiple lines.
+        } ## end if (ref($msg) ne '')
+        if ($msg =~ /\n/s) {         # If the line contains newlines, then it too must be split into multiple lines.
             my @message = split(/\n/, $msg);
-            foreach my $line (@message) {  # Loop through the split lines and format accordingly.
-                $self->_send_to_logger($level, $nested, $line, $first, $thisBench, $thisBench2, $subroutine, $cline,$sline,$short);
-                $first = FALSE;            # Clear the first line flag.
+            foreach my $line (@message) {    # Loop through the split lines and format accordingly.
+                $self->_send_to_logger($level, $nested, $line, $first, $thisBench, $thisBench2, $subroutine, $cline, $sline, $short);
+                $first = FALSE;              # Clear the first line flag.
             }
-        } else {                           # This line does not contain newlines.  Treat it as a single line.
-            $self->_send_to_logger($level, $nested, $msg, $first, $thisBench, $thisBench2, $subroutine, $cline,$sline,$short);
+        } else {    # This line does not contain newlines.  Treat it as a single line.
+            $self->_send_to_logger($level, $nested, $msg, $first, $thisBench, $thisBench2, $subroutine, $cline, $sline, $short);
         }
-        $first = FALSE;                    # Clear the first line flag.
-    }
-    $self->{'ANY_LASTSTAMP'}       = time;
+        $first = FALSE;    # Clear the first line flag.
+    } ## end foreach my $msg (@messages)
+    $self->{'ANY_LASTSTAMP'} = time;
     $self->{$level . '_LASTSTAMP'} = time;
-}
+} ## end sub debug
 
-sub _send_to_logger {    # This actually simplifies the previous object ... seriously
+sub _send_to_logger {      # This actually simplifies the previous object ... seriously
     my $self       = shift;
     my $level      = shift;
     my $padding    = shift;
@@ -653,7 +650,7 @@ sub _send_to_logger {    # This actually simplifies the previous object ... seri
     my $dt     = DateTime->now('time_zone' => $TIMEZONE);
     my $Date   = $dt->ymd();
     my $Time   = $dt->hms();
-    my $prefix = $self->{$level . '-PREFIX'} . ''; # A copy not a pointer
+    my $prefix = $self->{$level . '-PREFIX'} . '';    # A copy not a pointer
     my $forked = ($PARENT ne $$) ? 'C' : 'P';
 
     $prefix =~ s/\%PID\%/$$/g;
@@ -668,22 +665,23 @@ sub _send_to_logger {    # This actually simplifies the previous object ... seri
     $prefix =~ s/\%Filename\%/$self->{'FILENAME'}/g;
     $prefix =~ s/\%Fork\%/$forked/g;
     $prefix =~ s/\%Module\%/$subroutine/g;
+
     if ($first) {
         $prefix =~ s/\%Benchmark\%/$thisBench/g;
     } else {
         $prefix =~ s/\%Benchmark\%/$thisBench2/g;
     }
 
-    if ($level eq 'INFO' && $self->{'LOGLEVEL'} eq 'VERBOSE') { # Trap verbose flag and temporarily drop the prefix.
+    if ($level eq 'INFO' && $self->{'LOGLEVEL'} eq 'VERBOSE') {    # Trap verbose flag and temporarily drop the prefix.
         $self->{'LOG'}->INFO($msg);
-    } elsif ($level eq 'DEBUGMAX') {                            # Special version of DEBUG.  Outputs as DEBUG in Log::Fast
+    } elsif ($level eq 'DEBUGMAX') {                               # Special version of DEBUG.  Outputs as DEBUG in Log::Fast
         if ($self->{'LOGLEVEL'} eq 'DEBUGMAX') {
             $self->{'LOG'}->DEBUG($prefix . $padding . $msg);
         }
     } else {
         $self->{'LOG'}->$level($prefix . $padding . $msg);
     }
-}
+} ## end sub _send_to_logger
 
 =head2 ERR
 
@@ -700,7 +698,7 @@ Either a single string or a reference to a list of strings
 
 sub ERR {
     my $self = shift;
-    $self->debug('ERR',@_);
+    $self->debug('ERR', @_);
 }
 
 =head2 ERROR
@@ -718,7 +716,7 @@ Either a single string or a reference to a list of strings
 
 sub ERROR {
     my $self = shift;
-    $self->debug('ERR',@_);
+    $self->debug('ERR', @_);
 }
 
 =head2 WARN
@@ -736,7 +734,7 @@ Either a single string or a reference to a list of strings
 
 sub WARN {
     my $self = shift;
-    $self->debug('WARN',@_);
+    $self->debug('WARN', @_);
 }
 
 =head2 WARNING
@@ -754,7 +752,7 @@ Either a single string or a reference to a list of strings
 
 sub WARNING {
     my $self = shift;
-    $self->debug('WARN',@_);
+    $self->debug('WARN', @_);
 }
 
 =head2 NOTICE
@@ -772,7 +770,7 @@ Either a single string or a reference to a list of strings
 
 sub NOTICE {
     my $self = shift;
-    $self->debug('NOTICE',@_);
+    $self->debug('NOTICE', @_);
 }
 
 =head2 INFO
@@ -790,7 +788,7 @@ Either a single string or a reference to a list of strings
 
 sub INFO {
     my $self = shift;
-    $self->debug('INFO',@_);
+    $self->debug('INFO', @_);
 }
 
 =head2 INFORMATION
@@ -808,7 +806,7 @@ Either a single string or a reference to a list of strings
 
 sub INFORMATION {
     my $self = shift;
-    $self->debug('INFO',@_);
+    $self->debug('INFO', @_);
 }
 
 =head2 DEBUG
@@ -826,7 +824,7 @@ Either a single string or a reference to a list of strings
 
 sub DEBUG {
     my $self = shift;
-    $self->debug('DEBUG',@_);
+    $self->debug('DEBUG', @_);
 }
 
 =head2 DEBUGMAX
@@ -844,7 +842,7 @@ Either a single string or a reference to a list of strings
 
 sub DEBUGMAX {
     my $self = shift;
-    $self->debug('DEBUGMAX',@_);
+    $self->debug('DEBUGMAX', @_);
 }
 
 1;
@@ -855,6 +853,9 @@ Since it is possible to duplicate the object in a fork or thread, the output
 formatting may be mismatched between forks and threads due to the automatic
 padding adjustment of the subroutine name field.
 
+The "less" pager is the best for viewing log files generated by this module.
+It's switch "-r" allows you to see them in all their colorful glory.
+
 =head1 INSTALLATION
 
 To install this module, run the following commands:
@@ -882,7 +883,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 1.05    (July 27, 2015 Happy Birthday to me!)
+Version 1.06    (July 27, 2015)
 
 =head1 BUGS
 
